#!/usr/bin/env python
# -*- encoding: utf-8 -*-

# Run the server in development mode.

from packagesample.start import main
main()
